@@ -131,7 +131,7 @@ class GenericEpubConverter(GenericConverter):
             zp = zipfile.ZipFile(src_fp)
             if self.VERBOSE:
                 for info in zp.infolist():
-                    print(info.filename)
+                    print("  ", info.filename)
 
 
     def convert_html2md(self, html):
@@ -192,7 +192,9 @@ class GenericEpubConverter(GenericConverter):
                 in the epub file, in the order specified by the
                 table of contents
         """
+        print(len(html_files), "html_files found")
         html_files_dict = {os.path.split(fp)[-1] : fp for fp in html_files}
+        print("html_files_dict", html_files_dict)
         toc_data = zp.read(toc_fp)
         toc_data = codecs.decode(toc_data, "utf-8")
         soup = BeautifulSoup(toc_data)
@@ -310,7 +312,7 @@ Write the filename (with extension) of the table of contents
                     toc_fp = info.filename
                     if self.VERBOSE:
                         print("toc_fp", toc_fp)
-                elif info.filename.endswith("html"):
+                elif info.filename.endswith("html") or info.filename.endswith("htm"):
                     html_files.append(info.filename)
 
             # sort the list of the html files in the correct order:
