@@ -50,7 +50,7 @@ convert_files_in_folder             (inherited)
 convert file                        (inherited)
 make_dest_fp                        (inherited - generic!)
 get_metadata (dummy)                (inherited - dummy!)
-get_data                            get_data
+get_data                            (inherited)
 pre_process                         (inherited)
 add_page_numbers (dummy)            (inherited - dummy!)
 add_structural_annotations (dummy)  add_structural_annotations
@@ -313,7 +313,6 @@ class GenericHtmlConverter(GenericConverter):
         fp_list = self.filter_files_in_folder(folder, extensions,
                                                exclude_extensions)
         for fp in fp_list: 
-            print(fp)
             with open(fp, mode="r", encoding="utf-8") as file:
                 text = file.read()
                 if within_tag:
@@ -382,16 +381,18 @@ if __name__ == "__main__":
     print("Passed all tests.")
 
     conv = GenericHtmlConverter()
-    folder = r"G:\London\OpenITI\new\Rafed\test"
-##    conv.inspect_tags_in_folder(folder,
-##                                extensions=["html"],
-##                                only_tag_names=False,
-##                                strip_attr=["name", "href", "title"],
-##                                print_tags=True,
-##                                within_tag=("div", {"id": "content1"}))
 
-    conv.find_example_of_tag(folder, "p", attr={"class", "rfdCenterBold2"},
-                             n=15, incl_parent=True, extensions=["html"])
+    
+    folder = r"test\ghaemiyeh\epub\378"
+    conv.inspect_tags_in_folder(folder,
+                                extensions=["html", "htm"],
+                                only_tag_names=False,
+                                strip_attr=["name", "href", "title", "id"],
+                                print_tags=True,)
+                                #within_tag=("div", {"id": "content1"}))
+
+##    conv.find_example_of_tag(folder, "p", attr={"style": "margin:0pt; border:0pt; height:1em"},
+##                             n=15, incl_parent=True, extensions=["html", "htm"])
     
 ##    conv.convert_files_in_folder(folder)
 
